### Name: mpp
### Title: Marked Point Process Object
### Aliases: mpp
### Keywords: classes

### ** Examples

data(Tangshan)

#   increment magnitudes a fraction so none are zero
Tangshan[,"magnitude"] <- Tangshan[,"magnitude"] + 0.01

dmagn_mark <- function(x, data, params){
    #  Gamma distribution
    #  exponential density when params[7]=0
    #   See topic "marks" for further discussion
    lambda <- etas_gif(data, x[,"time"], params=params[1:5])
    y <- dgamma(x[,"magnitude"], shape=1+sqrt(lambda)*params[7],
                rate=params[6], log=TRUE)
    return(y)
}

TT <- c(0, 4018)
params <- c(0.007, 2.3, 0.98, 0.008, 0.94, 1.25, 0.2)

x <- mpp(data=Tangshan,
         gif=etas_gif,
         mark=list(dmagn_mark, NULL),
         params=params,
         gmap=expression(params[1:5]),
         mmap=expression(params[1:7]),
         TT=TT)

allmap <- function(y, p){
    #    one to one mapping
    y$params <- p
    return(y)
}

z <- nlm(neglogLik, params, object=x, updatep=allmap,
         print.level=2, iterlim=500, typsize=abs(params))

x1 <- allmap(x, z$estimate)

print(logLik(x))
print(logLik(x1))
plot(x1, log=TRUE)



